function y = FindLNparams(params,C,P,S,K,r,t);

% Find the lognormal mixture parameters
% C = vector of call market prices
% P = vector of put market prices
% S = spot
% K = vector of strikes
% r = risk free rate
% t = time to maturity

N = length(C);
M = (length(params)+1)/3;
m = params(1:M);
s = params(M+1:2*M);
p = params(2*M+1:end);
p(M) = 1 - sum(p(1:M-1));

% Squared differences between theoretical 
% and market prices of calls and puts.
for i=1:N
	Call(i) = LNmixPrice(K(i),S,m,s,p,r,t,'C');
	 Put(i) = LNmixPrice(K(i),S,m,s,p,r,t,'P');
	L(i) = (C(i) - Call(i))^2 + (P(i) - Put(i))^2;
end

% No arbitrage condition that theoretical and market
% spot prices should match. 
for i=1:M
	Arb(i) = exp(r*t)*p(i)*exp(m(i) + s(i)^2/2);
end;

% Objective function is the sum of squared differences between market and
% theoretical calls and puts and the no-arbitrage condition on the spot.
y = sum(L) + (S - (sum(Arb)))^2;

% Ensure that all parameters are positive.
if sum(m<=0)~=0 | sum(s<=0)~=0 | sum(p<0)~=0 | sum(p>1)~=0
	y = 1e10;
end
