function y = LNmixPrice(K,S,m,s,p,r,t,PutCall)

% Call price based on mixture of lognormals
% K = strike
% S = spot
% m = vector of lognormal means
% s = vector of lognormal standard deviations
% p = mixing weights
% r = risk free rate
% t = time to maturity
% PutCall = 'P' for put and 'C' for call

% Number of lognormals (usually M = 2)
M = length(m);

% Last mixing weight (pn = 1 - p1 - p2 - p3 ...)
p(M) = 1 - sum(p(1:M-1));

% The call price call be found in closed form, as a sum of lognormal terms.
for i=1:M
	Term1(i) = exp(-r*t)*p(i)*exp(m(i) + s(i)^2/2)*normcdf((m(i)+s(i)^2-log(K))/s(i));
	Term2(i) = exp(-r*t)*K*p(i)*normcdf((m(i)-log(K))/s(i));
end

% The call price.
Call = sum(Term1) - sum(Term2);

% The put price is by put-call parity.
if PutCall == 'C'
	y = Call;
else
	y = Call - S + K*exp(-r*t);
end	
